//////////////////////////////////////////////////////////////////////////
// Stereo Demo v1.1 - For the Conitec Winter 2008 Contest
// by Wagner Schieber <artista3d@gmail.com> - 2008.01.31
//////////////////////////////////////////////////////////////////////////

#include <acknex.h> // include these predefined, needed files in our project
#include <default.c>

//////////////////////////////////////////////////////////////////////////

// create the two split view cameras
VIEW* camera1 = {
	layer = 15;
	pos_x = 0;
	pos_y = 0;
	size_x = 400;
	size_y = 600;
	arc = 60;
	clip_far = 1000;
	flags = VISIBLE;
}

VIEW* camera2 = {
	layer = 15;
	pos_x = 400;
	pos_y = 0;
	size_x = 400;
	size_y = 600;
	arc = 60;
	clip_far = 1000;
	flags = VISIBLE; 
}

// splash screen
PANEL* mySplash = {
	bmap = "intro.jpg";
}

// entities
ENTITY* myBack1;
ENTITY* myBack2;
ENTITY* myBack3;
ENTITY* myBack4;
ENTITY* myBridge1;
ENTITY* myBridge2;
ENTITY* myDice1;
ENTITY* myDice2;
ENTITY* myFloor1;
ENTITY* myFloor2;
ENTITY* myFloor3;
ENTITY* myFloor4;
ENTITY* myHeart1;
ENTITY* myPlane;

// strings
STRING* MDLFloor1 = "Floor_01.mdl";
STRING* MDLBridge = "Bridge.mdl";
STRING* MDLPlane = "Plane.mdl";

// all function definitions and scenes
function initStereo() {
	//	d3d_antialias = 9; // does not work on Lite-C
	video_mode = 7; // 800x600
	video_screen = 1; // fullscreen
	screen_color.blue = vector(1, 1, 1); // screen color almost black
	sky_color.blue = vector(1, 1, 1); // sky color almost black
	set(mySplash,VISIBLE); // splash screen
	sun_light = 150; // set sunlight to 100
	level_load(""); 	// Load an empty level
	wait(3); // Wait until the level is loaded
	camera.flags = 0; // disable default camera
	// adjust the position and pan of the cameras to simulate eye separation
	camera1.y = -15;
	camera1.pan = 5;
	camera2.y = 15;
	camera2.pan = -5;
	while (0 == key_any) { // wait for keypress
		wait (1);
	}
	pan_remove(mySplash); // remove splash screen
}

function flyingDice1() {
	var myDuration = 1850; // duration of the scene in ticks
	myDice1 = ent_createlocal("Dice_01.mdl", vector(200, 0, 0), NULL); 	// create the model
	myBack1 = ent_createlocal("Back_01.mdl", vector(800, 0, 0), NULL); 	// create the model
	media_play("Music.mp3", NULL, 128); // start the music
	sun_angle.pan = 90;
	sun_angle.tilt = 30;
	var t;
	for(t=total_ticks; t<(total_ticks + myDuration); t++) {
		myDice1.pan += 3 * time_step;
		myDice1.tilt += 5 * time_step;
		myDice1.roll += 4 * time_step;
		myDice1.x = 350 - fsin(total_ticks * 5,100);
		myDice1.z = 5 + fcos(total_ticks * 3, 55);
		wait(1);
	}
	ent_purge(myDice1);
	ent_purge(myBack1);
}

function pumpingHeart() {
	var myDuration = 1750; // duration of the scene in ticks
	myHeart1 = ent_createlocal("Heart.mdl", vector(300, 0, 0), NULL); 	// create the model
	myBack3 = ent_createlocal("Back_03.mdl", vector(800, 0, 0), NULL); 	// create the model
	sun_angle.pan = 135;
	sun_angle.tilt = 30;
	var t;
	for(t=total_ticks; t<(total_ticks + myDuration); t++) {
		ent_fixnormals(myHeart1,1);
		myHeart1.pan -= 2 * time_step;
		myHeart1.z = fsin(total_ticks * 2, 50);
		myHeart1.scale_x = 1 - abs(fcos(total_ticks * 16, 0.1));
		myHeart1.scale_y = myHeart1.scale_x;
		myHeart1.scale_z = myHeart1.scale_x;
		wait(1);
	}
	ent_purge(myHeart1);
	ent_purge(myBack3);
}

function myPlane1() {
	var myDuration = 1760; // duration of the scene in ticks
	myFloor1 = ent_createlocal(MDLFloor1, vector(400, 0, 0), NULL); 	// create the model
	myFloor2 = ent_createlocal(MDLFloor1, vector(400, 0, 800), NULL); 	// create the model
	myFloor3 = ent_createlocal(MDLFloor1, vector(400, 0, 1600), NULL); 	// create the model
	myFloor4 = ent_createlocal(MDLFloor1, vector(400, 0, 2400), NULL); 	// create the model
	myBridge1 = ent_createlocal(MDLBridge, vector(400, 0, 850), NULL); 	// create the model
	myBridge2 = ent_createlocal(MDLBridge, vector(400, 0, 1550), NULL); 	// create the model
	myPlane = ent_createlocal(MDLPlane, vector(250, 0, 0), NULL); 	// create the model
	sun_angle.pan = 60;
	sun_angle.tilt = 185;
	var t;
	for(t=total_ticks; t<(total_ticks + myDuration); t++) {
		myFloor1.z -= 4 * time_step;
		myFloor2.z -= 4 * time_step;
		myFloor3.z -= 4 * time_step;
		myFloor4.z -= 4 * time_step;
		myBridge1.z -= 4 * time_step;
		myBridge2.z -= 4 * time_step;
		myPlane.x = 280 + fsin(0.31 * (myFloor1.z), 90);
		myPlane.tilt = 90 + fsin(0.31 * (myFloor1.z), 15);
		wait(1);
	}
	ent_purge(myFloor1);
	ent_purge(myFloor2);
	ent_purge(myFloor3);
	ent_purge(myFloor4);
	ent_purge(myBridge1);
	ent_purge(myBridge2);
	ent_purge(myPlane);
}

function flyingDice2() {
	var myDuration = 1760; // duration of the scene in ticks
	myDice2 = ent_createlocal("Dice_02.mdl", vector(200, 0, 0), NULL); 	// create the model
	myBack2 = ent_createlocal("Back_02.mdl", vector(800, 0, 0), NULL); 	// create the model
	sun_angle.pan = 60;
	sun_angle.tilt = 135;
	var t;
	for(t=total_ticks; t<(total_ticks + myDuration); t++) {
		myDice2.pan += 3 * time_step;
		myDice2.tilt += 5 * time_step;
		myDice2.roll += 4 * time_step;
		myDice2.x = 400 - fsin(total_ticks * 5,250);
		myDice2.y = fsin(total_ticks * 15, myDice2.x * 0.1);
		myDice2.z = 5 + fcos(total_ticks * 3, 55);
		sun_angle.pan += time_step;
		sun_angle.tilt += 3 * time_step;
		wait(1);
	}
	ent_purge(myDice2);
	ent_purge(myBack2);
}

function myCredits() {
	var myDuration1 = 880; // duration of the scene in ticks
	myBack4 = ent_createlocal("Back_04.mdl", vector(800, 0, 0), NULL); 	// create the model
	sun_angle.pan = 60;
	sun_angle.tilt = 135;
	var t;
	for(t=total_ticks; t<(total_ticks + myDuration1); t++) {
		myBack4.x += fsin(total_ticks * 10, 0.5);
		sun_angle.pan += time_step;
		sun_angle.tilt += 3 * time_step;
		wait(1);
	}
	bmap_load(bmap_for_entity(myBack4, 0), "Back_05.tga", 0);
	var myDuration2 = 880; 
	for(t=total_ticks; t<(total_ticks + myDuration2); t++) {
		myBack4.x += fsin(total_ticks * 10, 0.5);
		sun_angle.pan += time_step;
		sun_angle.tilt += 3 * time_step;
		wait(1);
	}
	ent_purge(myBack4);
}

// now let's get started!
function main() {
	initStereo(); // initiate stereo view
	wait_for(initStereo); // wait for initiation
	flyingDice1(); // scene
	wait_for(flyingDice1); // wait
	pumpingHeart(); // scene
	wait_for(pumpingHeart); // wait
	myPlane1(); // scene
	wait_for(myPlane1); // wait
	flyingDice2(); // scene
	wait_for(flyingDice2); // wait
	myCredits(); // scene
	wait_for(myCredits); // wait
	sys_exit(NULL);
}
